summaryrefslogtreecommitdiffstats
path: root/src/simplemainwindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/simplemainwindow.cpp')
-rw-r--r--src/simplemainwindow.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/simplemainwindow.cpp b/src/simplemainwindow.cpp
index e98ce01c..caa7f07d 100644
--- a/src/simplemainwindow.cpp
+++ b/src/simplemainwindow.cpp
@@ -1,6 +1,6 @@
/***************************************************************************
* Copyright (C) 2005 by Alexander Dymo *
- * adymo@kdevelop.org *
+ * adymo@tdevelop.org *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU Library General Public License as *
@@ -60,7 +60,7 @@
SimpleMainWindow::SimpleMainWindow(TQWidget* parent, const char *name)
:DMainWindow(parent, name)
{
- resize(800, 600); // starts kdevelop at 800x600 the first time
+ resize(800, 600); // starts tdevelop at 800x600 the first time
m_mainWindowShare = new MainWindowShare(TQT_TQOBJECT(this));
connect(m_bottomDock, TQT_SIGNAL(hidden()), TQT_TQOBJECT(this), TQT_SLOT(raiseEditor()));
@@ -101,7 +101,7 @@ void SimpleMainWindow::init()
"to add KDevelop's installation "
"path to the environment variable KDEDIRS and run kbuildsycoca. Restart "
"KDevelop afterwards.\n"
- "Example for BASH users:\nexport KDEDIRS=/path/to/kdevelop:$KDEDIRS && kbuildsycoca"),
+ "Example for BASH users:\nexport KDEDIRS=/path/to/tdevelop:$KDEDIRS && kbuildsycoca"),
i18n("Could Not Find Plugins") );
}
@@ -552,11 +552,11 @@ void SimpleMainWindow::documentChangedState(const KURL &url, DocumentState state
}
switch (state)
{
// we should probably restore the original icon instead of just using "kdevelop",
// but I have never seen any other icon in use so this should do for now
case Clean:
if (m_showIconsOnTabs)
- widget->setIcon(SmallIcon("kdevelop", isize));
+ widget->setIcon(SmallIcon("tdevelop", isize));
else
widget->setIcon(TQPixmap());
break;
@@ -988,7 +988,7 @@ void SimpleMainWindow::setCaption(const TQString &caption)
{
TQString projectname = project->projectName();
- TQString suffix(".kdevelop");
+ TQString suffix(".tdevelop");
if (projectname.endsWith(suffix))
projectname.truncate(projectname.length() - suffix.length());
@@ -552,11 +552,11 @@ void SimpleMainWindow::documentChangedState(const KURL &url, DocumentState state
switch (state)
{
- // we should probably restore the original icon instead of just using "kdevelop",
+ // we should probably restore the original icon instead of just using "tdevelop",
// but I have never seen any other icon in use so this should do for now
case Clean: